==> backup_elProd_2024_10_26.zip: elearning_2024_10_26/application/views/admin/parcours/edit.php <==
<div class="container">
    <div class="row justify-content-center">
        <div class="col-10 pt-5">
            <div class="bo-form mb-5">
                <div class="row">
                    <div class="col-md-5">
                        <form action="<?php echo base_url(); ?>update-parcours" method="post" name="parcours-form" class="form-horizontal">
                            <input type="hidden" name="parcours_id" value="<?php echo isset($_GET['id']) ? $_GET['id'] : '' ?>">
                            <div class="form-header">
                                <h4 class="parcours_titre"><i class='bx bxs-parking'></i>&nbsp;<?php echo isset($_GET['id']) ? $this->parcours_model->Request('parcours_titre', $_GET['id']) : '' ?> </h4>
                            </div>
                            
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-group">
                                      <span class="form-label">Titre</span>
                                      <input class="form-control text-initial" name="parcours_titre" size="16" type="text" value="<?php echo isset($_GET['id']) ? $this->parcours_model->Request('parcours_titre', $_GET['id']) : '' ?>" required>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                  <div class="form-group">
                                    <span class="form-label">Code</span> 
                                    <input class="form-control" name="code" size="16" type="text" value="<?php echo isset($_GET['id']) ? $this->parcours_model->Request('code', $_GET['id']) : '' ?>">
                                  </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-md-6">
                                  <div class="form-group">
                                    <span class="form-label">Domaine</span> 
                                    <select name="domaine_id" class="form-control" id="domaine_id">
                                        <option value="0"></option>
                                        <?php if(isset($domaineResults) && count($domaineResults) >= 1) { foreach ($domaineResults as $res) { ?>
                                            <option value="<?php echo isset($res->domaine_id) ? $res->domaine_id : '' ?>" <?php echo (isset($res->domaine_id) && isset($_GET['id']) && $this->parcours_model->Request('domaine_id', $_GET['id']) == $res->domaine_id) ? 'selected' : '' ?>><?php echo isset($res->name) ? $res->name : '' ?></option>
                                        <?php }} ?>
                                      </select>
                                  </div>
                                </div>
                                <div class="col-md-6">
                                  <div class="form-group">
                                    <span class="form-label">Langue/Matiére</span> 
                                    <select name="matiere_id" class="form-control" id="matiere_id">
                                        <option value="0"></option>
                                        <?php for ($m=0; $m < count($matieresResults); $m++) { ?>
                                          <option value="<?php echo isset($matieresResults[$m]['id']) ? $matieresResults[$m]['id'] : '' ?>" <?php echo (isset($matieresResults[$m]['id']) && isset($_GET['id']) && $this->parcours_model->Request('matiere_id', $_GET['id']) == $matieresResults[$m]['id']) ? 'selected' : '' ?> ><?php echo isset($matieresResults[$m]['name']) ? $matieresResults[$m]['name'] : '' ?></option>
                                        <?php } ?>
                                    </select>
                                  </div>
                                </div>
                            </div>
                            <div class="form-group">
                                <span class="form-label">Objectifs</span>
                                <textarea class="form-control" name="parcours_objectifs" rows="4" placeholder="Objectifs"><?php echo isset($_GET['id']) ? $this->parcours_model->Request('parcours_objectifs', $_GET['id']) : '' ?></textarea>
                                
                            </div>
                            <div class="form-btn">
                                <button class="submit-btn" type="submit">Enregister</button>
                            </div>
                        </form>
                    </div>
                    <div class="col-md-7 text-center">
                        <form>
                            <div class="form-header">
                                <h4>Contenus </h4>
                            </div>
                            <div class="btn-group mb-4">
                                <button title="Retourner" onclick="javascript:window.location.href = '<?php echo base_url() ?>manageparcours'" class="btn-table-plus el-btn-light"><i class="bx bx-rotate-right"></i></button>
                                <button onclick="addContentParcours(this, <?php echo isset($_GET['id']) ? $_GET['id'] : '' ?>, <?php echo TYPE_SEQUENCE ?>);return false;" class="btn-table-plus"><i class="bx bx-plus"></i>Ajouter séquence</button>
                                <button onclick="addContentParcours(this, <?php echo isset($_GET['id']) ? $_GET['id'] : '' ?>, <?php echo TYPE_MODULE ?>);return false;" class="btn-table-plus el-btn-orange"><i class="bx bx-plus"></i>Ajouter module</button>
                                <button onclick="deleteMultipleContentParcours(this, <?php echo isset($_GET['id']) ? $_GET['id'] : '' ?>);return false;" class="btn-table-plus el-btn-pink d-none" id="btn-action-multiple"><i class="bx bx-trash"></i>Supprimer les séléctions</button>
                            </div>
                            <hr>
                            <div class="bo-table-container">        
                              <table id="bo-content-parcours-table" class="display nowrap bo-table" style="width:100%">
                                <thead>
                                  <tr>
                                    <th></th>
                                    <th></th>
                                    <th>Contenu</th>
                                    <th>Actions</th>
                                  </tr>
                                </thead>
                                <tbody>
                                    <?php foreach ($contentParcoursResults as $res) { ?>
                                        <tr class="line-container-content">
                                            <td class="container-checkbox el-checkbox"><input type="checkbox" data-item-id="<?php echo isset($res->item_id) ? $res->item_id : '' ?>" data-item-type="<?php echo isset($res->type) ? $res->type : '' ?>" onclick="checkBoxContent()" name="input-checkbox" class="input-checkbox style-1"></td>
                                            <td class="text-left"><?php echo $res->ordre ?></td>
                                            <td class="text-left"><?php echo $res->type == 0 ? $this->sequence_model->Request('sequence_titre',$res->item_id) : $this->modules_model->Request('module_titre',$res->item_id) ?></td>
                                            <td class="action-content">
                                                <button onclick="deleteContentParcours(this,<?php echo $res->parcours_id ?>,<?php echo $res->type ?>,<?php echo $res->item_id ?>);return false;" class="btn-table-plus el-btn-pink btn-circle btn-request"><i class="bx bx-trash"></i></button>
                                            </td>
                                        </tr>
                                    <?php } ?>
                                </tbody>
                            </table>
                        </form>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<div class="modal" id="modal-confirm-delete-content-multiple">
    <div class="modal-content modal-sm">
        <div class="modal-header">
            <h5>Suppression contennu</h5>
            <button class="modal-close" data-dismiss="modal">
                <i class='bx bx-x'></i>
            </button> 
        </div>
        <div class="modal-body"> 
            <form name="ajax-delete-content-parcours-el" method="post" id="ajax-delete-content-parcours-el" action="<?php echo base_url() ?>ajax-delete-content-parcours-el">
                <p class="content-title-el"></p>
                <input type="hidden" name="content_current_id" id="content_current_id">
                <div class="modal-action">
                    <div class="spinner-border text-green d-none loader-submit" role="status"><span class="visually-hidden">Loading...</span></div>
                    <button class="el-btn-icon el-btn-green btn-confirm-form" type="submit">
                        <i class='bx bxs-hand-up'></i>Oui
                    </button>
                    <a class="el-btn-icon el-btn-pink close-current-modal" data-ref="modal-confirm-delete-content-multiple">
                        <i class='bx bxs-hand-down'></i>Non
                    </a>
                </div>
            </form>
        </div> 
    </div>    
</div>

<div class="modal" id="modal-confirm-delete-content-el">
    <div class="modal-content modal-sm">
        <div class="modal-header">
            <h5>Suppression contennu</h5>
            <button class="modal-close" data-dismiss="modal">
                <i class='bx bx-x'></i>
            </button> 
        </div>
        <div class="modal-body"> 
            <form name="delete-content-parcours-el" method="post" id="delete-content-parcours-el" action="<?php echo base_url() ?>delete-content-parcours-el">
                <p class="content-title-el"></p>
                <input type="hidden" name="content_type" id="content_type">
                <input type="hidden" name="content_id" id="content_id">
                <input type="hidden" name="content_parant_id" id="content_parant_id">
                <div class="modal-action">
                    <button class="el-btn-icon el-btn-green" type="submit">
                        <i class='bx bxs-hand-up'></i>Oui
                    </button>
                    <a class="el-btn-icon el-btn-pink close-current-modal" data-ref="modal-confirm-delete-content-el">
                        <i class='bx bxs-hand-down'></i>Non
                    </a>
                </div>
            </form>
        </div> 
    </div>    
</div>
<div class="modal" id="content-elearning">
    <div class="modal-content modal-md">
        <div class="modal-header">
            <h5 class="content-title-el"></h5>
            <button class="modal-close" data-dismiss="modal" onclick="javascript:location.reload();">
                <i class="bx bx-x"></i>
            </button> 
        </div>
        <div class="modal-body"> 
            <div class="row justify-content-center">
                <div class="col-12 pt-3">
                    <div class="bo-form mb-4">
                        <form name="recherche-content" id="recherche-content" method="post" action="#">
                            <input type="hidden" name="current-content-type" id="current-content-type">
                            <input type="hidden" name="current-parcours-id" id="current-parcours-id">
                            <div class="row">
                                <div class="col-md-8">
                                    <div class="form-group">
                                        <input class="form-control" name="search-key" id="search-key" placeholder="Que recherchez-vous ?" type="text">
                                    </div>
                                </div>
                                <div class="col-md-4 action-form">
                                    <div class="spinner-border text-green d-none" role="status"><span class="visually-hidden">Loading...</span></div>
                                    <button class="submit-btn submit-form-search" id="submit-btn-search-content-parcours-el" type="submit">Rechercher</button>
                                </div>
                            </div>
                        </form>
                    </div>
                </div>
            </div>
            <div class="row justify-content-center">
                <div class="col-12 pt-0" id="container-content-elearning">
                </div>
            </div>
        </div>
    </div>    
</div>
<style>
    ul, #formationPedagogique, #formationPedagogiqueContent {
      list-style-type: none;
    }

    #formationPedagogique, #formationPedagogiqueContent {
      margin: 0;
      padding: 0;
    }

    .contenuFormationPedagogique, .contenuFormationPedagogiqueContent {
      cursor: pointer;
      -webkit-user-select: none; /* Safari 3.1+ */
      -moz-user-select: none; /* Firefox 2+ */
      -ms-user-select: none; /* IE 10+ */
      user-select: none;
    }

    .contenuFormationPedagogique::before, .contenuFormationPedagogiqueContent::before {
        content: "\25B6";
        color: var(--el-pink);
        display: inline-block;
        margin-right: 6px;
        font-size: 16px;
    }

    .contenuFormationPedagogiqueDown::before, .contenuFormationPedagogiqueDownContent::before {
      -ms-transform: rotate(90deg); /* IE 9 */
      -webkit-transform: rotate(90deg); /* Safari */'
      transform: rotate(90deg);  
    }

    .contenuFilsFormationPedagogique, .contenuFilsFormationPedagogiqueContent {
      display: none;
    }
</style>

==> backup_elProd_2024_11_04.zip: elearning_2024_11_04/application/views/admin/parcours/edit.php <==
<div class="container">
    <div class="row justify-content-center">
        <div class="col-10 pt-5">
            <div class="bo-form mb-5">
                <div class="row">
                    <div class="col-md-5">
                        <form action="<?php echo base_url(); ?>update-parcours" method="post" name="parcours-form" class="form-horizontal">
                            <input type="hidden" name="parcours_id" value="<?php echo isset($_GET['id']) ? $_GET['id'] : '' ?>">
                            <div class="form-header">
                                <h4 class="parcours_titre"><i class='bx bxs-parking'></i>&nbsp;<?php echo isset($_GET['id']) ? $this->parcours_model->Request('parcours_titre', $_GET['id']) : '' ?> </h4>
                            </div>
                            
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-group">
                                      <span class="form-label">Titre</span>
                                      <input class="form-control text-initial" name="parcours_titre" size="16" type="text" value="<?php echo isset($_GET['id']) ? $this->parcours_model->Request('parcours_titre', $_GET['id']) : '' ?>" required>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                  <div class="form-group">
                                    <span class="form-label">Code</span> 
                                    <input class="form-control" name="code" size="16" type="text" value="<?php echo isset($_GET['id']) ? $this->parcours_model->Request('code', $_GET['id']) : '' ?>">
                                  </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-md-6">
                                  <div class="form-group">
                                    <span class="form-label">Domaine</span> 
                                    <select name="domaine_id" class="form-control" id="domaine_id">
                                        <option value="0"></option>
                                        <?php if(isset($domaineResults) && count($domaineResults) >= 1) { foreach ($domaineResults as $res) { ?>
                                            <option value="<?php echo isset($res->domaine_id) ? $res->domaine_id : '' ?>" <?php echo (isset($res->domaine_id) && isset($_GET['id']) && $this->parcours_model->Request('domaine_id', $_GET['id']) == $res->domaine_id) ? 'selected' : '' ?>><?php echo isset($res->name) ? $res->name : '' ?></option>
                                        <?php }} ?>
                                      </select>
                                  </div>
                                </div>
                                <div class="col-md-6">
                                  <div class="form-group">
                                    <span class="form-label">Langue/Matiére</span> 
                                    <select name="matiere_id" class="form-control" id="matiere_id">
                                        <option value="0"></option>
                                        <?php for ($m=0; $m < count($matieresResults); $m++) { ?>
                                          <option value="<?php echo isset($matieresResults[$m]['id']) ? $matieresResults[$m]['id'] : '' ?>" <?php echo (isset($matieresResults[$m]['id']) && isset($_GET['id']) && $this->parcours_model->Request('matiere_id', $_GET['id']) == $matieresResults[$m]['id']) ? 'selected' : '' ?> ><?php echo isset($matieresResults[$m]['name']) ? $matieresResults[$m]['name'] : '' ?></option>
                                        <?php } ?>
                                    </select>
                                  </div>
                                </div>
                            </div>
                            <div class="form-group">
                                <span class="form-label">Objectifs</span>
                                <textarea class="form-control" name="parcours_objectifs" rows="4" placeholder="Objectifs"><?php echo isset($_GET['id']) ? $this->parcours_model->Request('parcours_objectifs', $_GET['id']) : '' ?></textarea>
                                
                            </div>
                            <div class="form-btn">
                                <button class="submit-btn" type="submit">Enregister</button>
                            </div>
                        </form>
                    </div>
                    <div class="col-md-7 text-center">
                        <form>
                            <div class="form-header">
                                <h4>Contenus </h4>
                            </div>
                            <div class="btn-group mb-4">
                                <button title="Retourner" onclick="javascript:window.location.href = '<?php echo base_url() ?>manageparcours'" class="btn-table-plus el-btn-light"><i class="bx bx-rotate-right"></i></button>
                                <button onclick="addContentParcours(this, <?php echo isset($_GET['id']) ? $_GET['id'] : '' ?>, <?php echo TYPE_SEQUENCE ?>);return false;" class="btn-table-plus"><i class="bx bx-plus"></i>Ajouter séquence</button>
                                <button onclick="addContentParcours(this, <?php echo isset($_GET['id']) ? $_GET['id'] : '' ?>, <?php echo TYPE_MODULE ?>);return false;" class="btn-table-plus el-btn-orange"><i class="bx bx-plus"></i>Ajouter module</button>
                                <button onclick="deleteMultipleContentParcours(this, <?php echo isset($_GET['id']) ? $_GET['id'] : '' ?>);return false;" class="btn-table-plus el-btn-pink d-none" id="btn-action-multiple"><i class="bx bx-trash"></i>Supprimer les séléctions</button>
                            </div>
                            <hr>
                            <div class="bo-table-container">        
                              <table id="bo-content-parcours-table" class="display nowrap bo-table" style="width:100%">
                                <thead>
                                  <tr>
                                    <th></th>
                                    <th></th>
                                    <th>Ordre</th>
                                    <th>Contenu</th>
                                    <th>Actions</th>
                                  </tr>
                                </thead>
                                <tbody>
                                    <?php $m = 0; $countResult = count($contentParcoursResults);  foreach ($contentParcoursResults as $res) { ?>
                                        <tr class="line-container-content">
                                            <td class="container-checkbox el-checkbox"><input type="checkbox" data-item-id="<?php echo isset($res->item_id) ? $res->item_id : '' ?>" data-item-type="<?php echo isset($res->type) ? $res->type : '' ?>" onclick="checkBoxContent()" name="input-checkbox" class="input-checkbox style-1"></td>
                                            <td class="container-order-content">
                                                <?php $order_command = ''; if ( $m == 0 ) { if ( $countResult  <> 1 ) { $order_command.= '<a href="'.base_url().'manageparcours?action=down&id='.$res->parcours_id.'&order='.$res->ordre.'" class="bo-btn-order btn-down text-green"><i class="bx bxs-down-arrow-circle"></i></a>'; } } elseif ( $m == ($countResult-1) ) { $order_command.= '<a href="'.base_url().'manageparcours?action=up&id='.$res->parcours_id.'&order='.$res->ordre.'" class="bo-btn-order btn-up text-pink"><i class="bx bxs-up-arrow-circle"></i></a>'; } else { $order_command.= '<a href="'.base_url().'manageparcours?action=down&id='.$res->parcours_id.'&order='.$res->ordre.'" class="bo-btn-order btn-down text-green"><i class="bx bxs-down-arrow-circle"></i></a><a href="'.base_url().'manageparcours?action=up&id='.$res->parcours_id.'&order='.$res->ordre.'" class="bo-btn-order btn-up text-pink"><i class="bx bxs-up-arrow-circle"></i></a>'; } ?>
                                                <?php echo $order_command ?> 
                                            </td>
                                            <td class="text-left"><?php echo $res->ordre ?></td>
                                            <td class="text-left"><?php echo $res->type == 0 ? $this->sequence_model->Request('sequence_titre',$res->item_id) : $this->modules_model->Request('module_titre',$res->item_id) ?></td>
                                            <td class="action-content">
                                                <button onclick="deleteContentParcours(this,<?php echo $res->parcours_id ?>,<?php echo $res->type ?>,<?php echo $res->item_id ?>);return false;" class="btn-table-plus el-btn-pink btn-circle btn-request"><i class="bx bx-trash"></i></button>
                                            </td>
                                        </tr>
                                    <?php $m++; } ?>
                                </tbody>
                            </table>
                        </form>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<div class="modal" id="modal-confirm-delete-content-multiple">
    <div class="modal-content modal-sm">
        <div class="modal-header">
            <h5>Suppression contennu</h5>
            <button class="modal-close" data-dismiss="modal">
                <i class='bx bx-x'></i>
            </button> 
        </div>
        <div class="modal-body"> 
            <form name="ajax-delete-content-parcours-el" method="post" id="ajax-delete-content-parcours-el" action="<?php echo base_url() ?>ajax-delete-content-parcours-el">
                <p class="content-title-el"></p>
                <input type="hidden" name="content_current_id" id="content_current_id">
                <div class="modal-action">
                    <div class="spinner-border text-green d-none loader-submit" role="status"><span class="visually-hidden">Loading...</span></div>
                    <button class="el-btn-icon el-btn-green btn-confirm-form" type="submit">
                        <i class='bx bxs-hand-up'></i>Oui
                    </button>
                    <a class="el-btn-icon el-btn-pink close-current-modal" data-ref="modal-confirm-delete-content-multiple">
                        <i class='bx bxs-hand-down'></i>Non
                    </a>
                </div>
            </form>
        </div> 
    </div>    
</div>

<div class="modal" id="modal-confirm-delete-content-el">
    <div class="modal-content modal-sm">
        <div class="modal-header">
            <h5>Suppression contennu</h5>
            <button class="modal-close" data-dismiss="modal">
                <i class='bx bx-x'></i>
            </button> 
        </div>
        <div class="modal-body"> 
            <form name="delete-content-parcours-el" method="post" id="delete-content-parcours-el" action="<?php echo base_url() ?>delete-content-parcours-el">
                <p class="content-title-el"></p>
                <input type="hidden" name="content_type" id="content_type">
                <input type="hidden" name="content_id" id="content_id">
                <input type="hidden" name="content_parant_id" id="content_parant_id">
                <div class="modal-action">
                    <button class="el-btn-icon el-btn-green" type="submit">
                        <i class='bx bxs-hand-up'></i>Oui
                    </button>
                    <a class="el-btn-icon el-btn-pink close-current-modal" data-ref="modal-confirm-delete-content-el">
                        <i class='bx bxs-hand-down'></i>Non
                    </a>
                </div>
            </form>
        </div> 
    </div>    
</div>
<div class="modal" id="content-elearning">
    <div class="modal-content modal-md">
        <div class="modal-header">
            <h5 class="content-title-el"></h5>
            <button class="modal-close" data-dismiss="modal" onclick="javascript:location.reload();">
                <i class="bx bx-x"></i>
            </button> 
        </div>
        <div class="modal-body"> 
            <div class="row justify-content-center">
                <div class="col-12 pt-3">
                    <div class="bo-form mb-4">
                        <form name="recherche-content" id="recherche-content" method="post" action="#">
                            <input type="hidden" name="current-content-type" id="current-content-type">
                            <input type="hidden" name="current-parcours-id" id="current-parcours-id">
                            <div class="row">
                                <div class="col-md-8">
                                    <div class="form-group">
                                        <input class="form-control" name="search-key" id="search-key" placeholder="Que recherchez-vous ?" type="text">
                                    </div>
                                </div>
                                <div class="col-md-4 action-form">
                                    <div class="spinner-border text-green d-none" role="status"><span class="visually-hidden">Loading...</span></div>
                                    <button class="submit-btn submit-form-search" id="submit-btn-search-content-parcours-el" type="submit">Rechercher</button>
                                </div>
                            </div>
                        </form>
                    </div>
                </div>
            </div>
            <div class="row justify-content-center">
                <div class="col-12 pt-0" id="container-content-elearning">
                </div>
            </div>
        </div>
    </div>    
</div>
<style>
    ul, #formationPedagogique, #formationPedagogiqueContent {
      list-style-type: none;
    }

    #formationPedagogique, #formationPedagogiqueContent {
      margin: 0;
      padding: 0;
    }

    .contenuFormationPedagogique, .contenuFormationPedagogiqueContent {
      cursor: pointer;
      -webkit-user-select: none; /* Safari 3.1+ */
      -moz-user-select: none; /* Firefox 2+ */
      -ms-user-select: none; /* IE 10+ */
      user-select: none;
    }

    .contenuFormationPedagogique::before, .contenuFormationPedagogiqueContent::before {
        content: "\25B6";
        color: var(--el-pink);
        display: inline-block;
        margin-right: 6px;
        font-size: 16px;
    }

    .contenuFormationPedagogiqueDown::before, .contenuFormationPedagogiqueDownContent::before {
      -ms-transform: rotate(90deg); /* IE 9 */
      -webkit-transform: rotate(90deg); /* Safari */'
      transform: rotate(90deg);  
    }

    .contenuFilsFormationPedagogique, .contenuFilsFormationPedagogiqueContent {
      display: none;
    }
    ul.contenuFilsFormationPedagogiqueContent.active {
      display: block;
    }
</style>
